// src/global_settings.cc - Copyright 2005, 2006, University
//               of Padova, dept. of Pure and Applied
//               Mathematics
//
// This file is part of SGPEMv2.
//
// This is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// SGPEMv2 is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with SGPEMv2; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

#include "config.h"
#include "global_settings.hh"

using namespace sgpem;

GlobalSettings* GlobalSettings::_instance = 0;

GlobalSettings& 
GlobalSettings::instance()
{
    if(!_instance)
	_instance = new GlobalSettings();
    return *_instance;
}


GlobalSettings::GlobalSettings()
    : _mod_dirs(1, PLUGDIR), _pol_dirs(1, POLDIR)
{}


GlobalSettings::dir_iterator
GlobalSettings::policies_dir_begin() const
{
    return _pol_dirs.begin();
}


GlobalSettings::dir_iterator
GlobalSettings::policies_dir_end() const
{
    return _pol_dirs.end();
}


GlobalSettings::dir_iterator
GlobalSettings::modules_dir_begin() const
{
    return _mod_dirs.begin();
}


GlobalSettings::dir_iterator
GlobalSettings::modules_dir_end() const
{
    return _mod_dirs.end();
}


void 
GlobalSettings::add_modules_dir(const Glib::ustring& moddir)
{
    _mod_dirs.insert(_mod_dirs.begin(), moddir);
}


void 
GlobalSettings::add_policies_dir(const Glib::ustring& poldir)
{
    _pol_dirs.insert(_pol_dirs.begin(), poldir);
}

